:math:`x(n) \longleftrightarrow X(z)`

:math:`x(- m + n) \longleftrightarrow z^{- m} X(z)`

:math:`\cos{\left(2 \pi \Delta_{t} f_{0} n \right)} \longleftrightarrow \frac{z \left(z - \cos{\left(2 \pi \Delta_{t} f_{0} \right)}\right)}{z^{2} - 2 z \cos{\left(2 \pi \Delta_{t} f_{0} \right)} + 1}`

:math:`\sin{\left(2 \pi \Delta_{t} f_{0} n \right)} \longleftrightarrow \frac{z \sin{\left(2 \pi \Delta_{t} f_{0} \right)}}{z^{2} - 2 z \cos{\left(2 \pi \Delta_{t} f_{0} \right)} + 1}`

:math:`e^{2 \mathrm{j} \pi \Delta_{t} f_{0} n} \longleftrightarrow \frac{z}{z - e^{2 \mathrm{j} \pi \Delta_{t} f_{0}}}`

:math:`1 \longleftrightarrow \frac{1}{1 - \frac{1}{z}}`

:math:`\delta\left[n\right] \longleftrightarrow 1`

:math:`\delta\left[n - p\right] \longleftrightarrow \left(\frac{1}{z}\right)^{p}`

:math:`a^{n} \longleftrightarrow \frac{z}{- a + z}`

:math:`a^{- n} \longleftrightarrow \frac{a z}{a z - 1}`

:math:`a^{n} n \longleftrightarrow \frac{a z}{\left(a - z\right)^{2}}`

:math:`a^{- n} n \longleftrightarrow \frac{a z}{\left(a z - 1\right)^{2}}`

:math:`u\left[n\right] \longleftrightarrow \frac{1}{1 - \frac{1}{z}}`

:math:`e^{- \Delta_{t} n} u\left[n\right] \longleftrightarrow \frac{z e^{\Delta_{t}}}{z e^{\Delta_{t}} - 1}`

